==> cscec5b-rmat-api-3.0.1-20221021.093018-17-sources.jar: com/ejianc/business/rmat/vo/ExitDetailGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.math.BigDecimal;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitDetailGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String exitId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String stopDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private BigDecimal applyNums; // 申请退场数量
    private BigDecimal exitNums; // 本次退场数量
    private BigDecimal exitNumsSum; // 累计退场数量

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getExitId() {
        return exitId;
    }

    public void setExitId(String exitId) {
        this.exitId = exitId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getStopDate() {
        return stopDate;
    }

    public void setStopDate(String stopDate) {
        this.stopDate = stopDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
}

==> cscec5b-rmat-api-3.0.1-20230712.113245-230-sources.jar: com/ejianc/business/rmat/vo/ExitDetailGFVO.java <==
package com.ejianc.business.rmat.vo;

import java.math.BigDecimal;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitDetailGFVO {
    private static final long serialVersionUID = 1L;

    private String id;
    private String exitId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String stopDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private BigDecimal applyNums; // 申请退场数量
    private BigDecimal exitNums; // 本次退场数量
    private BigDecimal exitNumsSum; // 累计退场数量

    private String rentUnitName; // 计租单位
    private BigDecimal rentNum; // 计租数量
    private BigDecimal rentExitNum; // 申请退场数量(计租)
    private BigDecimal realExitNum; // 申请退场数量(实物)
    private BigDecimal rentOutNum; // 计租退场数量
    private BigDecimal realOutNum; // 实物退场数量

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getExitId() {
        return exitId;
    }

    public void setExitId(String exitId) {
        this.exitId = exitId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getStopDate() {
        return stopDate;
    }

    public void setStopDate(String stopDate) {
        this.stopDate = stopDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public BigDecimal getRentExitNum() {
        return rentExitNum;
    }

    public void setRentExitNum(BigDecimal rentExitNum) {
        this.rentExitNum = rentExitNum;
    }

    public BigDecimal getRealExitNum() {
        return realExitNum;
    }

    public void setRealExitNum(BigDecimal realExitNum) {
        this.realExitNum = realExitNum;
    }

    public BigDecimal getRentOutNum() {
        return rentOutNum;
    }

    public void setRentOutNum(BigDecimal rentOutNum) {
        this.rentOutNum = rentOutNum;
    }

    public BigDecimal getRealOutNum() {
        return realOutNum;
    }

    public void setRealOutNum(BigDecimal realOutNum) {
        this.realOutNum = realOutNum;
    }
}
